@@ -15,6 +15,7 @@ FREQ_3S = 3000
 FREQ_5S = 5000
 FREQ_15S = 15000
 FREQ_30S = 30000
+FREQ_45S = 45000
 FREQ_1M = 60000
 FREQ_3M = 180000
 FREQ_5M = 300000
@@ -34,6 +35,7 @@ FREQUENCIES = [
     FREQ_5S,
     FREQ_15S,
     FREQ_30S,
+    FREQ_45S,
     FREQ_1M,
     FREQ_3M,
     FREQ_5M,
